@@ -168,77 +168,3 @@ signi <- which(moranI$p < 0.05)
 signi
 plot(mem.gab[,signi], SpORcoords = xyir, nb = nbgab)
 
-## ------------------------------------------------------------------------
-data(oribatid)
-fau <- sqrt(oribatid$fau / outer(apply(oribatid$fau, 1, sum),
-    rep(1, ncol(oribatid$fau)), "*"))
-faudt <- resid(lm(as.matrix(fau) ~ as.matrix(oribatid$xy)))
-
-## ------------------------------------------------------------------------
-nbtri <- tri2nb(as.matrix(oribatid$xy))
-sc.tri <- scores.listw(nb2listw(nbtri, style = "B"))
-AIC.tri <- ortho.AIC(faudt, sc.tri)
-head(AIC.tri)
-
-## ------------------------------------------------------------------------
-min(AIC.tri, na.rm = TRUE)
-which.min(AIC.tri)
-
-## ------------------------------------------------------------------------
-AIC.tri <- ortho.AIC(faudt, sc.tri, ord.var = TRUE)
-head(AIC.tri$AICc)
-head(AIC.tri$ord)
-
-## ------------------------------------------------------------------------
-tri.res <- test.W(faudt,nbtri)
-names(tri.res)
-names(tri.res$best)
-
-## ------------------------------------------------------------------------
-f2 <- function(x, dmax, y) {
-    1 - (x ^ y) / (dmax) ^ y
-}
-
-maxi <- max(unlist(nbdists(nbtri, as.matrix(oribatid$xy))))
-tri.f2 <- test.W(faudt, nbtri, f = f2, y = 2:10, dmax = maxi, 
-    xy = as.matrix(oribatid$xy))
-
-## ------------------------------------------------------------------------
-names(tri.f2$best)
-
-## ---- fig.height = 5, fig.width = 5--------------------------------------
-mvspec <- variogmultiv(faudt, oribatid$xy, nclass = 20)
-plot(mvspec$d, mvspec$var, type = 'b', pch = 20, xlab = "Distance", ylab = "C(distance)")
-
-## ------------------------------------------------------------------------
-dxy <- seq(give.thresh(dist(oribatid$xy)), 4, length = 10)
-nbdnnlist <- lapply(dxy, dnearneigh, x = as.matrix(oribatid$xy), d1 = 0)
-
-## ------------------------------------------------------------------------
-dnn.bin <- lapply(nbdnnlist, test.W, Y = faudt)
-
-## ------------------------------------------------------------------------
-length(dnn.bin)
-
-## ------------------------------------------------------------------------
-minAIC <- sapply(dnn.bin, function(x) min(x$best$AIC$AICc, na.rm = TRUE))
-
-## ------------------------------------------------------------------------
-which.min(minAIC)
-dxy[which.min(minAIC)]
-
-## ------------------------------------------------------------------------
-f2 <- function(x,dmax,y) {1-(x^y)/(dmax)^y}
-
-## ------------------------------------------------------------------------
-dnn.f2 <- lapply(nbdnnlist, function(x) 
-    test.W(x, Y = faudt, f = f2, y = 2:10, 
-        dmax = max(unlist(nbdists(x, as.matrix(oribatid$xy)))), xy = as.matrix(oribatid$xy)))
-minAIC <- sapply(dnn.f2, function(x) min(x$best$AIC$AICc, na.rm = TRUE))
-min(minAIC)
-which.min(minAIC)
-dnn.f2[[which.min(minAIC)]]$all
-
-## ---- fig.width = 5, fig.height = 5/3------------------------------------
-plot(dnn.f2[[7]]$best$MEM[, dnn.f2[[7]]$best$AIC$ord[1:3]], oribatid$xy)
-
